@@ -1,4 +1,7 @@
 from django.contrib.auth import authenticate, login
+from django.core.urlresolvers import reverse
+from django.shortcuts import redirect
+from github.exceptions import BadVerificationCode
 from github.models import Authentication, User
 
 
@@ -6,7 +9,13 @@ class GithubAuthorizationMiddleware(object):
     def process_request(self, request):
         if request.GET.get('code') and request.GET.get('state'):
             auth = Authentication.objects.get(pk=request.GET.get('state'))
-            access_token = auth.get_access_token(request.GET['code'])
+            try:
+                access_token = auth.get_access_token(request.GET['code'])
+            except BadVerificationCode:
+                return redirect(reverse('github:authorize', kwargs={
+                    'pk': auth.application.pk
+                }))
+
             user = auth.application.request('user', headers={
                 'Authorization': 'token %s' % access_token
             })
@@ -21,6 +30,7 @@ class GithubAuthorizationMiddleware(object):
                     'access_token': access_token
                 }
             )
+
             if not created:
                 github_user.access_token = access_token
                 github_user.save()
