@@ -6,6 +6,8 @@ import operator
 import requests
 
 # 1.4 Compatibility
+from github.exceptions import BadVerificationCode
+
 AUTH_USER_MODEL = getattr(settings, 'AUTH_USER_MODEL', 'auth.User')
 
 
@@ -39,7 +41,7 @@ class Authentication(models.Model):
         base_url = 'https://github.com/login/oauth/authorize'
         auth_args = {
             'client_id': self.application.client_id,
-            'redirect_url': self.redirect_uri
+            'redirect_uri': self.redirect_uri
         }
         if self.scope:
             auth_args['scope'] = self.scope
@@ -59,6 +61,9 @@ class Authentication(models.Model):
             'code': code
         }, headers={'Accept': 'application/json'}).json()
 
+        if response.get('error') == 'bad_verification_code':
+            raise BadVerificationCode()
+
         return response['access_token']
 
 
